Print

Print


Commit in lcsim/src/org/lcsim/recon/tracking/seedtracker on MAIN
MaterialManager.java+16-61.8 -> 1.9
handle HPS detector type using SiTrackerEndcap2VolumeGrouper

lcsim/src/org/lcsim/recon/tracking/seedtracker
MaterialManager.java 1.8 -> 1.9
diff -u -r1.8 -r1.9
--- MaterialManager.java	11 Feb 2011 15:49:03 -0000	1.8
+++ MaterialManager.java	3 Mar 2011 21:37:58 -0000	1.9
@@ -31,18 +31,19 @@
 import org.lcsim.geometry.subdetector.SiTrackerBarrel;
 import org.lcsim.geometry.subdetector.SiTrackerEndcap;
 import org.lcsim.geometry.subdetector.SiTrackerEndcap2;
+import org.lcsim.geometry.subdetector.SiTrackerFixedTarget2;
 
 /**
  * Rewrite and refactor of Rich's {@link MaterialManager} class to handle Subdetector types. 
  * This class should now group together SiTrackerEndcap2 layers correctly.
  * 
  * @author Jeremy McCormick
- * @version $Id: MaterialManager.java,v 1.8 2011/02/11 15:49:03 partridge Exp $
+ * @version $Id: MaterialManager.java,v 1.9 2011/03/03 21:37:58 jeremy Exp $
  */
 public class MaterialManager
 {
     // Variables from original MaterialManager class.
-    private static final boolean DEBUG = false; // enable debug output
+    private boolean DEBUG = false; // enable debug output to System.out
     private static final boolean TUBE_ONLY = false; // only use Tube elements
     // for calculating volume.
     private List<MaterialPolyconeSegment> _matpc = new ArrayList<MaterialPolyconeSegment>();
@@ -177,14 +178,23 @@
         subdetGroups.put(SiTrackerEndcap.class, endcapGrouper);
         subdetGroups.put(DiskTracker.class, endcapGrouper);
 
-        // Add VolumeGrouper for SiTrackerEndcap2.
-        subdetGroups.put(SiTrackerEndcap2.class, new SiTrackerEndap2VolumeGrouper());
+        // Add VolumeGrouper for SiTrackerEndcap2 and SiTrackerFixedTarget2.
+        SubdetectorVolumeGrouper endcapGrouper2 = new SiTrackerEndap2VolumeGrouper();
+        subdetGroups.put(SiTrackerEndcap2.class, endcapGrouper2);
+        subdetGroups.put(SiTrackerFixedTarget2.class, endcapGrouper2);
 
         // Add VolumeGrouper for PolyconeSupport.
         subdetGroups.put(PolyconeSupport.class, new PolyconeSupportVolumeGrouper());        
     }
-
-
+    
+    /**
+     * Turn on/off debugging output.
+     * @param debug True if debugging should be enabled; false if not.
+     */
+    public void setDebug(boolean debug)
+    {
+        this.DEBUG = debug;
+    }
 
     /**
      * Setup tracking volume parameters.
CVSspam 0.2.8